@@ -1,5 +1,8 @@
 # -*- coding: utf-8 -*-
 #
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
 # Copyright 2004-2022 Univention GmbH
 #
 # https://www.univention.de/
@@ -200,7 +203,21 @@ property_descriptions = {
 		options=['posix'],
 		dontsearch=True,
 		copyable=True,
-	)
+	),
+	'univentionObjectIdentifier': univention.admin.property(
+		short_description=_('Immutable Object Identifier'),
+		long_description=_('Immutable attribute to track the identity of an object in UDM'),
+		syntax=univention.admin.syntax.string,
+		may_change=False,
+		dontsearch=True,
+	),
+	'univentionSourceIAM': univention.admin.property(
+		short_description=_('Immutable Identifier of the source IAM'),
+		long_description=_('Immutable attribute to identfy source IAM'),
+		syntax=univention.admin.syntax.string,
+		may_change=False,
+		dontsearch=True,
+	),
 }
 
 layout = [
@@ -255,6 +272,8 @@ mapping.register('sambaPrivileges', 'univentionSambaPrivilegeList', encoding='AS
 mapping.register('allowedEmailUsers', 'univentionAllowedEmailUsers')
 mapping.register('allowedEmailGroups', 'univentionAllowedEmailGroups')
 mapping.registerUnmapping('sambaRID', unmapSambaRid)
+mapping.register('univentionObjectIdentifier', 'univentionObjectIdentifier', None, univention.admin.mapping.ListToString)
+mapping.register('univentionSourceIAM', 'univentionSourceIAM', None, univention.admin.mapping.ListToString)
 
 
 class AgingCache(object):
@@ -436,7 +455,7 @@ class object(univention.admin.handlers.simpleLdap):
 		super(object, self)._ldap_pre_ready()
 
 		# get lock for name
-		if not self.exists() or self.hasChanged('name') and self['name'].lower() != self.oldinfo['name'].lower():
+		if self['name'] and (not self.exists() or self.hasChanged('name') and self['name'].lower() != self.oldinfo['name'].lower()):
 			try:
 				self.request_lock('groupName', self['name'])
 			except univention.admin.uexceptions.noLock:
@@ -458,6 +477,11 @@ class object(univention.admin.handlers.simpleLdap):
 		else:
 			self['gidNumber'] = self.request_lock('gidNumber')
 
+		if self['univentionObjectIdentifier']:
+			univention.admin.allocators.acquireUnique(self.lo, self.position, 'univentionObjectIdentifier', self['univentionObjectIdentifier'], 'univentionObjectIdentifier', scope='base')
+			# "False" ==> do not update univentionLastUsedValue in LDAP if a specific value has been specified
+			self.alloc.append(('univentionObjectIdentifier', self['univentionObjectIdentifier'], False))
+
 		self.check_for_group_recursion()
 		self._check_uid_gid_uniqueness()
 
