@@ -364,7 +364,7 @@ class object(univention.admin.handlers.simpleLdap):
 
 	@classmethod
 	def _ldap_attributes(cls):
-		return [u'*', u'pwdAccountLockedTime']
+		return super(object, cls)._ldap_attributes() + ['pwdAccountLockedTime']
 
 
 lookup = object.lookup
